@@ -1,9 +1,13 @@
+pub(crate) mod author;
+pub(crate) mod datetime;
+pub(crate) mod toc;
+
 use super::*;
 
 pub struct DocumentMeta {
     pub title: Option<String>,
-    pub author: Vec<String>,
-    pub date: Option<NaiveDateTime>,
+    authors: BTreeMap<String, DocumentAuthor>,
+    date: Option<DocumentTime>,
     pub toc: TocNode,
 }
 
