@@ -1,16 +1,13 @@
 mod parser;
-
-pub use self::parser::PluginParser;
-use crate::FileMeta;
-use notedown_ast::{utils::DashMap, ASTNode, Result};
+pub use self::parser::{Parser, PluginParser};
+use notedown_ast::ASTNode;
+use notedown_error::{NoteError, Result};
 use std::{
     collections::BTreeSet,
-    fmt::{Debug, Formatter},
+    fmt::{Debug, Display, Formatter},
     hash::{Hash, Hasher},
 };
-
-/// A parser which can parse text into ast, and report errors at the same time
-pub type Parser = fn(&str, &mut FileMeta) -> Result<ASTNode>;
+use yggdrasil_shared::records::DashMap;
 
 /// Plugin system manager
 #[derive(Debug, Default)]
